@@ -10,12 +10,13 @@ import webbrowser
 import os
 import re
 import time
-import json
+import pickle
 import imp
 from sys import platform as _platform
 import subprocess as sp
 import inspect
 
+
 def loaddata(marketlist=None, refresh=False):
 
 
@@ -130,7 +131,9 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
         TSobject=tradingSystem
     elif os.path.isfile(tradingSystem):
         filePathFlag=True
-        filePath=tradingSystem
+        filePath=str(tradingSystem)
+        tsFolder,tsName= os.path.split(filePath)
+
 
         try:
             TSmodule=imp.load_source('tradingSystemModule',filePath)
@@ -213,6 +216,8 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
             print('Resuming'+tsName+'| computing' +str(nDays-startLoop+1)+' new days')
             settings= state['ret']['settings']
 
+    ret={}
+
 
     t0= time.time()
 
@@ -309,7 +314,7 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
             raise
             break
 
-    # Reset to contest settings (used for various contest evaluations)
+#        Reset to contest settings (used for various contest evaluations)
 #         settings['lookback'] = 504
 #         settings['budget'] = 10**6
 #         settings['slippage'] = 0.05
@@ -327,13 +332,17 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
             break
 
 
+    fundequity = settings['budget'] + np.sum(equity[(settings['lookback']-1):,:],axis=1)
+    if plotEquity:
+        statistics,returns = plotts(fundequity,DATE[settings['lookback']-1:])
+    else:
+        statistics,returns = stats(fundequity)
 
 
-
-
+    ret['tsName']=tsName
     ret['fundDate']=DATE
     ret['fundTradeDates']=DATE[settings['lookback']:]
-    ret['fundEquity']=settings['budget']+np.sum(equity[settings['lookback']:,:],axis=1)
+    ret['fundEquity']=fundequity
     ret['marketEquity']= equity
     ret['marketExposure'] = exposure[2:,:]
     ret['settings']=settings
@@ -341,33 +350,16 @@ def runts(tradingSystem, plotEquity=True, reloadData=False, state={}):
     ret['runtime']=runtime
     ret['stats']=stats(ret['fundEquity'])
     ret['evalDate']=DATE[t]
+#    ret['evaluated']=np.sum(DATE<=DATE(t))/np.size(DATE)
+    ret['stats']=statistics
+    ret['settings']=settings
+
 
     if state['save']:
-        with open(tsName+'.json') as fileID:
-            stateSave=json.dump(state,fileID)
+        with open(tsName+'.pickle') as fileID:
+            stateSave=pickle.dump(state,fileID)
 
-
-
-
-    fundequity = settings['budget'] + np.sum(equity[(settings['lookback']-1):,:],axis=1)
-    np.savetxt('/Users/vnredmon/Desktop/eqCurve.csv',fundequity,delimiter=",")
-
-    np.savetxt('/Users/vnredmon/Desktop/pyExposure.csv',exposure,delimiter=",")
-
-
-    if plotEquity:
-        statistics,returns = plotts(fundequity,DATE[settings['lookback']-1:])
-    else:
-        statistics,returns = stats(fundequity)
-    results={}
-    results['equity']=equity
-    results['exposure']=exposure
-    results['errorlog']=errorlog
-    results['stats']=statistics
-    results['settings']=settings
-    results['ret']=ret
-
-    return results
+    return ret
 
 
 def plotts(equity,DATE):
@@ -563,13 +555,48 @@ def submit(tradingSystem, tsName):
     webbrowser.open_new_tab('http://www.quantiacs.com/quantnetsite/UploadSuccess.aspx?guid='+str(the_page))
 
 
-def simpleTS(DATE, OPEN, HIGH, LOW, CLOSE, VOL, exposure, equity, settings):
 
-    nMarkets=CLOSE.shape[1]
-    pos=np.ones((1,nMarkets))*0.001
-    cash=settings['budget'] + np.sum(equity[-1,:])*0.95
-    pos=pos*cash/CLOSE[-1,:]
-    return pos, settings
+def computeFees(equity, managementFee,performanceFee):
+    ret = np.diff(equity) / equity[:-1]
+    ret = np.append(0,ret)
+
+    tradeDays = ret > 0
+    firstTradeDayRow = np.where(tradeDays==True)
+    firstTradeDay = firstTradeDayRow[0][0]
+
+
+    manFeeIx = np.zeros(np.shape(ret),dtype=bool)
+    manFeeIx[firstTradeDay:] = 1
+    ret[manFeeIx] = ret[manFeeIx] - managementFee/252;
+
+    ret = 1 + ret
+    r = np.ndarray((0,0))
+    high = 1
+    last = 1
+    pFee = np.zeros(np.shape(ret))
+    mFee = np.zeros(np.shape(ret))
+
+    for k in range(len(ret)):
+        mFee[k] = last * managementFee/252 * equity[0]
+        if last * ret[0] > high:
+            iFix = high / last
+            iPerf = ret[k] / iFix
+            iPerf = 1 + (iPerf - 1) * (1-performanceFee)
+            pFee[k] = (iPerf - 1) * (performanceFee) * high * equity[0]
+            r=np.append(r,iPerf * iFix)
+        else:
+            r=np.append(r,ret[k])
+        if np.size(r)>0:
+            last = r[-1] * last
+        if last > high:
+            high = last
+
+
+    out = np.cumprod(r)
+    out = out * equity[0]
+    return out
+
+
 
 def fillnans(inArr):
 
@@ -583,7 +610,7 @@ def fillnans(inArr):
     return inArr
 
 def fillwith(field, lookup):
-#    pdb.set_trace()
+
     out = field
     nanPos= np.where(np.isnan(out[2:,:]));
     nanRow=nanPos[0]
